searchData={"items":[{"type":"task","title":"mix nx_iree.native_download","doc":"Downloads the native IREE library for the requested platform.\n\nCurrently only supported in macOS arm64 hosts.","ref":"Mix.Tasks.NxIree.NativeDownload.html"},{"type":"module","title":"NxIREE","doc":"IREE compiler and runtime bindings for Nx.\n\nNxIREE provides an `Nx.Defn` compiler which runs on [IREE](https://iree.dev).\nThe following example shows how we can compile a function to run on the CPU:\n\n    f = &Nx.add/2\n    compiler_flags = [\"--iree-hal-target-backends=llvm-cpu\", \"--iree-input-type=stablehlo_xla\", \"--iree-execution-model=async-internal\"]\n    opts = [compiler: NxIREE.Compiler, iree_compiler_flags: compiler_flags, iree_runtime_options: [device: \"local-sync://\"])\n    Nx.Defn.compile(f, [Nx.template({1}, :f32), Nx.template({3}, :f32)], opts)\n\nAnd this next example compiles the same function for running on the Apple GPU through Metal:\n\n    f = &Nx.add/2\n    compiler_flags = [\"--iree-hal-target-backends=metal-spirv\", \"--iree-input-type=stablehlo_xla\", \"--iree-execution-model=async-internal\"]\n    opts = [compiler: NxIREE.Compiler, iree_compiler_flags: compiler_flags, iree_runtime_options: [device: \"metal://\"])\n    Nx.Defn.compile(f, [Nx.template({1}, :f32), Nx.template({3}, :f32)], opts)\n\n`NxIREE.Compiler` also provides a `to_bytecode` function which outputs the bytecode for usage with embedded devices,\nsuch as the iOS devices usable through [`LiveNxIREE`](https://github.com/elixir-nx/nx_iree/tree/main/embedded_devices/live_nx_iree).","ref":"NxIREE.html"},{"type":"function","title":"NxIREE.call/3","doc":"Calls a function in the given module with the provided Nx inputs.","ref":"NxIREE.html#call/3"},{"type":"function","title":"Options - NxIREE.call/3","doc":"# `:function` - The name of the function to call in the module. If not provided, will default to `\"main\"`.\n  * `:device` - The device to run the module on. If not provided, will default to known GPU devices (CUDA, ROCm, Metal, Vulkan) over others.\n    Valid values can be obtained through `list_devices/0` or `list_devices/1`.","ref":"NxIREE.html#call/3-options"},{"type":"function","title":"NxIREE.compile/3","doc":"Compiles the given MLIR module with the given list of flags.\n\nReturns the bytecode for the compiled module.","ref":"NxIREE.html#compile/3"},{"type":"function","title":"Examples - NxIREE.compile/3","doc":"iex> mlir_module = \"\"\"\n    ...> func.func @main(%arg0: tensor<4xf32>, %arg1: tensor<4xf32>) -> tensor<4xf32> {\n    ...>   %0 = \"stablehlo.multiply\"(%arg0, %arg1) : (tensor<4xf32>, tensor<4xf32>) -> tensor<4xf32>\n    ...>   return %0 : tensor<4xf32>\n    ...> }\n    ...>\"\"\"\n    iex> flags = [\"--iree-hal-target-backends=llvm-cpu\", \"--iree-input-type=stablehlo_xla\", \"--iree-execution-model=async-internal\"]\n    iex> NxIREE.compile(mlir_module, flags)","ref":"NxIREE.html#compile/3-examples"},{"type":"function","title":"NxIREE.list_devices/0","doc":"Lists all devices available for running IREE modules.","ref":"NxIREE.html#list_devices/0"},{"type":"function","title":"NxIREE.list_devices/1","doc":"Lists all devices available in a given driver for running IREE modules.\n\nValid drivers can be obtained through `list_drivers/0`.","ref":"NxIREE.html#list_devices/1"},{"type":"function","title":"NxIREE.list_drivers/0","doc":"Lists all drivers available for running IREE modules.","ref":"NxIREE.html#list_drivers/0"},{"type":"module","title":"NxIREE.Backend","doc":"A thin `Nx.Backend` implementation for IREE.\n\nProvides simple `from_binary/2` and `to_binary/1` calls, as well as\nhandling output buffer references for IREE call outputs.","ref":"NxIREE.Backend.html"},{"type":"module","title":"NxIREE.Compiler","doc":"Compiler for Nx defn","ref":"NxIREE.Compiler.html"},{"type":"function","title":"NxIREE.Compiler.to_bytecode/3","doc":"","ref":"NxIREE.Compiler.html#to_bytecode/3"},{"type":"module","title":"NxIREE.Module","doc":"","ref":"NxIREE.Module.html"},{"type":"function","title":"NxIREE.Module.__struct__/0","doc":"Holds the bytecode and other metadata for a compiled MLIR module.","ref":"NxIREE.Module.html#__struct__/0"},{"type":"type","title":"NxIREE.Module.t/0","doc":"","ref":"NxIREE.Module.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.0.1 (2024-10-04) - Changelog","doc":"First release, including an Nx.Defn compiler and companion Nx.Backend.","ref":"changelog.html#v0-0-1-2024-10-04"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}